@@ -26,9 +26,9 @@
 
 #include <KConfigGroup>
 #include <QDialogButtonBox>
-#include <QHBoxLayout>
 #include <QLabel>
 #include <QPushButton>
+#include <QVBoxLayout>
 
 using namespace MailCommon;
 
