@@ -22,9 +22,7 @@
 
 #include "filteraction.h"
 
-namespace MailCommon
-{
-
+namespace MailCommon {
 /**
  *  @short Abstract base class for filter actions with no parameter.
  *
@@ -52,19 +50,18 @@ public:
     /**
      * @copydoc FilterAction::argsFromString
      */
-    void argsFromString(const QString &) Q_DECL_OVERRIDE;
+    void argsFromString(const QString &) override;
 
     /**
      * @copydoc FilterAction::argsAsString
      */
-    QString argsAsString() const Q_DECL_OVERRIDE;
+    QString argsAsString() const override;
 
     /**
      * @copydoc FilterAction::displayString
      */
-    QString displayString() const Q_DECL_OVERRIDE;
+    QString displayString() const override;
 };
-
 }
 
 #endif
